==> jc-1.4.0.tar.gz: javax/swing/text/DefaultEditorKit.h <==
// public class javax.swing.text.DefaultEditorKit

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b73385988de3a8cb javax_swing_text_DefaultEditorKit
// @dep_class 24d74fb32d567cd2 javax_swing_text_EditorKit

// header file dependencies
// @dep_header javax_swing_text_EditorKit

#include "javax/swing/text/EditorKit.h"

#ifndef _JC_javax_swing_text_DefaultEditorKit_H_
#define _JC_javax_swing_text_DefaultEditorKit_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_io_OutputStream$object;
struct _jc_java_io_Reader$object;
struct _jc_java_io_Writer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_text_Caret$object;
struct _jc_javax_swing_text_Document$object;
struct _jc_javax_swing_text_ViewFactory$object;

// Typedefs
typedef struct _jc_javax_swing_text_DefaultEditorKit$sub_refs	_jc_javax_swing_text_DefaultEditorKit$sub_refs;
typedef struct _jc_javax_swing_text_DefaultEditorKit$sub_nonrefs	_jc_javax_swing_text_DefaultEditorKit$sub_nonrefs;
typedef struct _jc_javax_swing_text_DefaultEditorKit$refs	_jc_javax_swing_text_DefaultEditorKit$refs;
typedef struct _jc_javax_swing_text_DefaultEditorKit$nonrefs	_jc_javax_swing_text_DefaultEditorKit$nonrefs;
typedef struct _jc_javax_swing_text_DefaultEditorKit$object	_jc_javax_swing_text_DefaultEditorKit$object;

typedef struct _jc_javax_swing_text_DefaultEditorKit$fields_struct	_jc_javax_swing_text_DefaultEditorKit$fields_struct;
typedef const struct _jc_javax_swing_text_DefaultEditorKit$vmethods	_jc_javax_swing_text_DefaultEditorKit$vmethods;
typedef const struct _jc_javax_swing_text_DefaultEditorKit$vtable	_jc_javax_swing_text_DefaultEditorKit$vtable;
typedef const struct _jc_javax_swing_text_DefaultEditorKit$vtype	_jc_javax_swing_text_DefaultEditorKit$vtype;

// Class fields structure
struct _jc_javax_swing_text_DefaultEditorKit$fields_struct {
	struct _jc_java_lang_String$object	*EndOfLineStringProperty;
	struct _jc_java_lang_String$object	*backwardAction;
	struct _jc_java_lang_String$object	*beepAction;
	struct _jc_java_lang_String$object	*beginAction;
	struct _jc_java_lang_String$object	*beginLineAction;
	struct _jc_java_lang_String$object	*beginParagraphAction;
	struct _jc_java_lang_String$object	*beginWordAction;
	struct _jc_java_lang_String$object	*copyAction;
	struct _jc_java_lang_String$object	*cutAction;
	_jc_object_array	*defaultActions;
	struct _jc_java_lang_String$object	*defaultKeyTypedAction;
	struct _jc_java_lang_String$object	*deleteNextCharAction;
	struct _jc_java_lang_String$object	*deletePrevCharAction;
	struct _jc_java_lang_String$object	*downAction;
	struct _jc_java_lang_String$object	*endAction;
	struct _jc_java_lang_String$object	*endLineAction;
	struct _jc_java_lang_String$object	*endParagraphAction;
	struct _jc_java_lang_String$object	*endWordAction;
	struct _jc_java_lang_String$object	*forwardAction;
	struct _jc_java_lang_String$object	*insertBreakAction;
	struct _jc_java_lang_String$object	*insertContentAction;
	struct _jc_java_lang_String$object	*insertTabAction;
	struct _jc_java_lang_String$object	*nextWordAction;
	struct _jc_java_lang_String$object	*pageDownAction;
	struct _jc_java_lang_String$object	*pageUpAction;
	struct _jc_java_lang_String$object	*pasteAction;
	struct _jc_java_lang_String$object	*previousWordAction;
	struct _jc_java_lang_String$object	*readOnlyAction;
	struct _jc_java_lang_String$object	*selectAllAction;
	struct _jc_java_lang_String$object	*selectLineAction;
	struct _jc_java_lang_String$object	*selectParagraphAction;
	struct _jc_java_lang_String$object	*selectWordAction;
	struct _jc_java_lang_String$object	*selectionBackwardAction;
	struct _jc_java_lang_String$object	*selectionBeginAction;
	struct _jc_java_lang_String$object	*selectionBeginLineAction;
	struct _jc_java_lang_String$object	*selectionBeginParagraphAction;
	struct _jc_java_lang_String$object	*selectionBeginWordAction;
	struct _jc_java_lang_String$object	*selectionDownAction;
	struct _jc_java_lang_String$object	*selectionEndAction;
	struct _jc_java_lang_String$object	*selectionEndLineAction;
	struct _jc_java_lang_String$object	*selectionEndParagraphAction;
	struct _jc_java_lang_String$object	*selectionEndWordAction;
	struct _jc_java_lang_String$object	*selectionForwardAction;
	struct _jc_java_lang_String$object	*selectionNextWordAction;
	struct _jc_java_lang_String$object	*selectionPreviousWordAction;
	struct _jc_java_lang_String$object	*selectionUpAction;
	struct _jc_java_lang_String$object	*upAction;
	struct _jc_java_lang_String$object	*writableAction;
	jlong	serialVersionUID;
};
extern _jc_javax_swing_text_DefaultEditorKit$fields_struct _jc_javax_swing_text_DefaultEditorKit$class_fields;

// Constructors
extern void _jc_javax_swing_text_DefaultEditorKit$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit$object *);

// Virtual methods
extern struct _jc_object *_jc_javax_swing_text_DefaultEditorKit$method$createCaret$64b4f7538da1571d(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit$object *);
extern struct _jc_object *_jc_javax_swing_text_DefaultEditorKit$method$createDefaultDocument$d6c78a75f6dbe003(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit$object *);
extern _jc_object_array *_jc_javax_swing_text_DefaultEditorKit$method$getActions$ea1976429372941d(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit$object *);
extern struct _jc_java_lang_String$object *_jc_javax_swing_text_DefaultEditorKit$method$getContentType$c8e5b99f03eb0f46(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit$object *);
extern struct _jc_object *_jc_javax_swing_text_DefaultEditorKit$method$getViewFactory$7b0683a833033cb8(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit$object *);
extern void _jc_javax_swing_text_DefaultEditorKit$method$read$e7a65c52adc487e1(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit$object *, struct _jc_java_io_InputStream$object *, struct _jc_object *, jint);
extern void _jc_javax_swing_text_DefaultEditorKit$method$read$26c9628b52fea300(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit$object *, struct _jc_java_io_Reader$object *, struct _jc_object *, jint);
extern void _jc_javax_swing_text_DefaultEditorKit$method$write$e16efd799de70c27(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit$object *, struct _jc_java_io_OutputStream$object *, struct _jc_object *, jint, jint);
extern void _jc_javax_swing_text_DefaultEditorKit$method$write$4d009ba87f7c5d8f(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit$object *, struct _jc_java_io_Writer$object *, struct _jc_object *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_DefaultEditorKit$method_info$createCaret$64b4f7538da1571d;
extern _jc_method _jc_javax_swing_text_DefaultEditorKit$method_info$createDefaultDocument$d6c78a75f6dbe003;
extern _jc_method _jc_javax_swing_text_DefaultEditorKit$method_info$getActions$ea1976429372941d;
extern _jc_method _jc_javax_swing_text_DefaultEditorKit$method_info$getContentType$c8e5b99f03eb0f46;
extern _jc_method _jc_javax_swing_text_DefaultEditorKit$method_info$getViewFactory$7b0683a833033cb8;
extern _jc_method _jc_javax_swing_text_DefaultEditorKit$method_info$read$e7a65c52adc487e1;
extern _jc_method _jc_javax_swing_text_DefaultEditorKit$method_info$read$26c9628b52fea300;
extern _jc_method _jc_javax_swing_text_DefaultEditorKit$method_info$write$e16efd799de70c27;
extern _jc_method _jc_javax_swing_text_DefaultEditorKit$method_info$write$4d009ba87f7c5d8f;

// Static methods
extern void _jc_javax_swing_text_DefaultEditorKit$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_javax_swing_text_DefaultEditorKit$vmethods {
	struct _jc_object	*(*createCaret$64b4f7538da1571d)(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit$object *);
	struct _jc_object	*(*createDefaultDocument$d6c78a75f6dbe003)(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit$object *);
	_jc_object_array	*(*getActions$ea1976429372941d)(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit$object *);
	struct _jc_java_lang_String$object	*(*getContentType$c8e5b99f03eb0f46)(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit$object *);
	struct _jc_object	*(*getViewFactory$7b0683a833033cb8)(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit$object *);
	void	(*read$e7a65c52adc487e1)(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit$object *, struct _jc_java_io_InputStream$object *, struct _jc_object *, jint);
	void	(*read$26c9628b52fea300)(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit$object *, struct _jc_java_io_Reader$object *, struct _jc_object *, jint);
	void	(*write$e16efd799de70c27)(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit$object *, struct _jc_java_io_OutputStream$object *, struct _jc_object *, jint, jint);
	void	(*write$4d009ba87f7c5d8f)(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit$object *, struct _jc_java_io_Writer$object *, struct _jc_object *, jint, jint);
};

// Vtable
struct _jc_javax_swing_text_DefaultEditorKit$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_EditorKit$vmethods	javax_swing_text_EditorKit;
	_jc_javax_swing_text_DefaultEditorKit$vmethods	javax_swing_text_DefaultEditorKit;
};

// Vtype
struct _jc_javax_swing_text_DefaultEditorKit$vtype {
	_jc_type			type;
	_jc_javax_swing_text_DefaultEditorKit$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_DefaultEditorKit$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_DefaultEditorKit$refs {
    _jc_javax_swing_text_DefaultEditorKit$sub_refs	javax_swing_text_DefaultEditorKit;
    _jc_javax_swing_text_EditorKit$sub_refs	javax_swing_text_EditorKit;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_DefaultEditorKit$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_DefaultEditorKit$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_EditorKit$sub_nonrefs	javax_swing_text_EditorKit;
    _jc_javax_swing_text_DefaultEditorKit$sub_nonrefs	javax_swing_text_DefaultEditorKit;
};

// Object instance structure
struct _jc_javax_swing_text_DefaultEditorKit$object {
	_jc_javax_swing_text_DefaultEditorKit$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_DefaultEditorKit$vtype	*vtype;
	_jc_javax_swing_text_DefaultEditorKit$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_DefaultEditorKit$vtype _jc_javax_swing_text_DefaultEditorKit$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_DefaultEditorKit, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_DefaultEditorKit$class_object;

#endif	/* _JC_javax_swing_text_DefaultEditorKit_H_ */

==> jc-1.4.5.tar.gz: javax/swing/text/DefaultEditorKit.h <==
// public class javax.swing.text.DefaultEditorKit

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class caa20ff98450f590 javax_swing_text_DefaultEditorKit
// @dep_class 24d74fb32d567cd2 javax_swing_text_EditorKit

// header file dependencies
// @dep_header javax_swing_text_EditorKit

#include "javax/swing/text/EditorKit.h"

#ifndef _JC_javax_swing_text_DefaultEditorKit_H_
#define _JC_javax_swing_text_DefaultEditorKit_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_io_OutputStream$object;
struct _jc_java_io_Reader$object;
struct _jc_java_io_Writer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_text_Caret$object;
struct _jc_javax_swing_text_Document$object;
struct _jc_javax_swing_text_ViewFactory$object;

// Typedefs
typedef struct _jc_javax_swing_text_DefaultEditorKit$sub_refs	_jc_javax_swing_text_DefaultEditorKit$sub_refs;
typedef struct _jc_javax_swing_text_DefaultEditorKit$sub_nonrefs	_jc_javax_swing_text_DefaultEditorKit$sub_nonrefs;
typedef struct _jc_javax_swing_text_DefaultEditorKit$refs	_jc_javax_swing_text_DefaultEditorKit$refs;
typedef struct _jc_javax_swing_text_DefaultEditorKit$nonrefs	_jc_javax_swing_text_DefaultEditorKit$nonrefs;
typedef struct _jc_javax_swing_text_DefaultEditorKit$object	_jc_javax_swing_text_DefaultEditorKit$object;

typedef struct _jc_javax_swing_text_DefaultEditorKit$fields_struct	_jc_javax_swing_text_DefaultEditorKit$fields_struct;
typedef const struct _jc_javax_swing_text_DefaultEditorKit$vmethods	_jc_javax_swing_text_DefaultEditorKit$vmethods;
typedef const struct _jc_javax_swing_text_DefaultEditorKit$vtable	_jc_javax_swing_text_DefaultEditorKit$vtable;
typedef const struct _jc_javax_swing_text_DefaultEditorKit$vtype	_jc_javax_swing_text_DefaultEditorKit$vtype;

// Class fields structure
struct _jc_javax_swing_text_DefaultEditorKit$fields_struct {
	struct _jc_java_lang_String$object	*EndOfLineStringProperty;
	struct _jc_java_lang_String$object	*backwardAction;
	struct _jc_java_lang_String$object	*beepAction;
	struct _jc_java_lang_String$object	*beginAction;
	struct _jc_java_lang_String$object	*beginLineAction;
	struct _jc_java_lang_String$object	*beginParagraphAction;
	struct _jc_java_lang_String$object	*beginWordAction;
	struct _jc_java_lang_String$object	*copyAction;
	struct _jc_java_lang_String$object	*cutAction;
	_jc_object_array	*defaultActions;
	struct _jc_java_lang_String$object	*defaultKeyTypedAction;
	struct _jc_java_lang_String$object	*deleteNextCharAction;
	struct _jc_java_lang_String$object	*deletePrevCharAction;
	struct _jc_java_lang_String$object	*downAction;
	struct _jc_java_lang_String$object	*endAction;
	struct _jc_java_lang_String$object	*endLineAction;
	struct _jc_java_lang_String$object	*endParagraphAction;
	struct _jc_java_lang_String$object	*endWordAction;
	struct _jc_java_lang_String$object	*forwardAction;
	struct _jc_java_lang_String$object	*insertBreakAction;
	struct _jc_java_lang_String$object	*insertContentAction;
	struct _jc_java_lang_String$object	*insertTabAction;
	struct _jc_java_lang_String$object	*nextWordAction;
	struct _jc_java_lang_String$object	*pageDownAction;
	struct _jc_java_lang_String$object	*pageUpAction;
	struct _jc_java_lang_String$object	*pasteAction;
	struct _jc_java_lang_String$object	*previousWordAction;
	struct _jc_java_lang_String$object	*readOnlyAction;
	struct _jc_java_lang_String$object	*selectAllAction;
	struct _jc_java_lang_String$object	*selectLineAction;
	struct _jc_java_lang_String$object	*selectParagraphAction;
	struct _jc_java_lang_String$object	*selectWordAction;
	struct _jc_java_lang_String$object	*selectionBackwardAction;
	struct _jc_java_lang_String$object	*selectionBeginAction;
	struct _jc_java_lang_String$object	*selectionBeginLineAction;
	struct _jc_java_lang_String$object	*selectionBeginParagraphAction;
	struct _jc_java_lang_String$object	*selectionBeginWordAction;
	struct _jc_java_lang_String$object	*selectionDownAction;
	struct _jc_java_lang_String$object	*selectionEndAction;
	struct _jc_java_lang_String$object	*selectionEndLineAction;
	struct _jc_java_lang_String$object	*selectionEndParagraphAction;
	struct _jc_java_lang_String$object	*selectionEndWordAction;
	struct _jc_java_lang_String$object	*selectionForwardAction;
	struct _jc_java_lang_String$object	*selectionNextWordAction;
	struct _jc_java_lang_String$object	*selectionPreviousWordAction;
	struct _jc_java_lang_String$object	*selectionUpAction;
	struct _jc_java_lang_String$object	*upAction;
	struct _jc_java_lang_String$object	*writableAction;
	jlong	serialVersionUID;
};
extern _jc_javax_swing_text_DefaultEditorKit$fields_struct _jc_javax_swing_text_DefaultEditorKit$class_fields;

// Constructors
extern void _jc_javax_swing_text_DefaultEditorKit$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_javax_swing_text_DefaultEditorKit$method$createCaret$64b4f7538da1571d(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_text_DefaultEditorKit$method$createDefaultDocument$d6c78a75f6dbe003(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_javax_swing_text_DefaultEditorKit$method$getActions$ea1976429372941d(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_swing_text_DefaultEditorKit$method$getContentType$c8e5b99f03eb0f46(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_text_DefaultEditorKit$method$getViewFactory$7b0683a833033cb8(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_text_DefaultEditorKit$method$read$e7a65c52adc487e1(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit$object *, struct _jc_java_io_InputStream$object *, struct _jc_object *, jint) _JC_JCNI_ATTR;
extern void _jc_javax_swing_text_DefaultEditorKit$method$read$26c9628b52fea300(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit$object *, struct _jc_java_io_Reader$object *, struct _jc_object *, jint) _JC_JCNI_ATTR;
extern void _jc_javax_swing_text_DefaultEditorKit$method$write$e16efd799de70c27(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit$object *, struct _jc_java_io_OutputStream$object *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_javax_swing_text_DefaultEditorKit$method$write$4d009ba87f7c5d8f(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit$object *, struct _jc_java_io_Writer$object *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_DefaultEditorKit$method_info$createCaret$64b4f7538da1571d;
extern _jc_method _jc_javax_swing_text_DefaultEditorKit$method_info$createDefaultDocument$d6c78a75f6dbe003;
extern _jc_method _jc_javax_swing_text_DefaultEditorKit$method_info$getActions$ea1976429372941d;
extern _jc_method _jc_javax_swing_text_DefaultEditorKit$method_info$getContentType$c8e5b99f03eb0f46;
extern _jc_method _jc_javax_swing_text_DefaultEditorKit$method_info$getViewFactory$7b0683a833033cb8;
extern _jc_method _jc_javax_swing_text_DefaultEditorKit$method_info$read$e7a65c52adc487e1;
extern _jc_method _jc_javax_swing_text_DefaultEditorKit$method_info$read$26c9628b52fea300;
extern _jc_method _jc_javax_swing_text_DefaultEditorKit$method_info$write$e16efd799de70c27;
extern _jc_method _jc_javax_swing_text_DefaultEditorKit$method_info$write$4d009ba87f7c5d8f;

// Static methods
extern void _jc_javax_swing_text_DefaultEditorKit$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_text_DefaultEditorKit$vmethods {
	struct _jc_object	*(*createCaret$64b4f7538da1571d)(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*createDefaultDocument$d6c78a75f6dbe003)(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit$object *) _JC_JCNI_ATTR;
	_jc_object_array	*(*getActions$ea1976429372941d)(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getContentType$c8e5b99f03eb0f46)(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getViewFactory$7b0683a833033cb8)(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit$object *) _JC_JCNI_ATTR;
	void	(*read$e7a65c52adc487e1)(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit$object *, struct _jc_java_io_InputStream$object *, struct _jc_object *, jint) _JC_JCNI_ATTR;
	void	(*read$26c9628b52fea300)(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit$object *, struct _jc_java_io_Reader$object *, struct _jc_object *, jint) _JC_JCNI_ATTR;
	void	(*write$e16efd799de70c27)(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit$object *, struct _jc_java_io_OutputStream$object *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;
	void	(*write$4d009ba87f7c5d8f)(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit$object *, struct _jc_java_io_Writer$object *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_text_DefaultEditorKit$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_EditorKit$vmethods	javax_swing_text_EditorKit;
	_jc_javax_swing_text_DefaultEditorKit$vmethods	javax_swing_text_DefaultEditorKit;
};

// Vtype
struct _jc_javax_swing_text_DefaultEditorKit$vtype {
	_jc_type			type;
	_jc_javax_swing_text_DefaultEditorKit$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_DefaultEditorKit$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_DefaultEditorKit$refs {
    _jc_javax_swing_text_DefaultEditorKit$sub_refs	javax_swing_text_DefaultEditorKit;
    _jc_javax_swing_text_EditorKit$sub_refs	javax_swing_text_EditorKit;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_DefaultEditorKit$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_DefaultEditorKit$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_EditorKit$sub_nonrefs	javax_swing_text_EditorKit;
    _jc_javax_swing_text_DefaultEditorKit$sub_nonrefs	javax_swing_text_DefaultEditorKit;
};

// Object instance structure
struct _jc_javax_swing_text_DefaultEditorKit$object {
	_jc_javax_swing_text_DefaultEditorKit$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_DefaultEditorKit$vtype	*vtype;
	_jc_javax_swing_text_DefaultEditorKit$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_DefaultEditorKit$vtype _jc_javax_swing_text_DefaultEditorKit$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_DefaultEditorKit, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_DefaultEditorKit$class_object;

#endif	/* _JC_javax_swing_text_DefaultEditorKit_H_ */
